@@ -9,12 +9,15 @@ class LightHouseDataExtract:
     def __init__(self, path_to_json='./report/lighthouse/',url_category_file=None,from_api=False):
 
        self.jsonpath_page_size = parse("$.audits.total-byte-weight")
-       self.jsonpath_first_meaningful_paint = parse("$.audits.first-meaningful-paint")
        self.jsonpath_first_contentful_paint = parse("$.audits.first-contentful-paint")
-       self.jsonpath_interactive = parse("$.audits.interactive")
-       self.jsonpath_max_potential_fid = parse("$.audits.max-potential-fid")
-       self.jsonpath_score = parse("$.categories.performance.score")
+       self.jsonpath_largest_contentful_paint = parse("$.audits.largest-contentful-paint")
+       self.jsonpath_first_meaningful_paint = parse("$.audits.first-meaningful-paint")
        self.jsonpath_speed_index = parse("$.audits.speed-index")
+       self.jsonpath_total_blocking_time = parse("$.audits.total-blocking-time")
+       self.jsonpath_max_potential_fid = parse("$.audits.max-potential-fid")
+       self.jsonpath_server_response_time = parse("$.audits.server-response-time")
+       self.jsonpath_interactive = parse("$.audits.interactive")
+       self.jsonpath_score = parse("$.categories.performance.score")
        self.jsonpath_network_resources =  parse("$.audits.network-requests.details.items")
        self.jsonpath_audit = parse("$.audits.audit_name")
 
@@ -30,6 +33,7 @@ class LightHouseDataExtract:
        self.opportunities_data = [] 
        self.diagnostics_data = []
        self.resources_data = []
+       self.network_resources = []
        self.report = self.get_report()
 
     def find_url_category_dict(self):
@@ -39,8 +43,8 @@ class LightHouseDataExtract:
            result = OrderedDict(zip(df['url'], df['category']))
         return result
 
-    def df_lh_perf_metrics(self):
-        df = pd.DataFrame(self.lh_perf_metrics_data, columns = ['url','fetch_time','category','page_size','score','first_contentful_paint','max_potential_fid','time_to_interactive','first_meaningful_paint','speed_index'])
+    def df_report(self):
+        df = pd.DataFrame(self.lh_perf_metrics_data, columns = ['url','fetch_time','category','page_size','score','first_contentful_paint','largest_contentful_paint','first_meaningful_paint','speed_index','total_blocking_time','max_potential_fid','server_response_time','interactive'])
         return df
     def df_opportunities(self):
         df = pd.DataFrame(self.opportunities_data,columns=['url','fetch_time','category','audit_text','estimated_savings'])
@@ -65,24 +69,36 @@ class LightHouseDataExtract:
  
     def find_lh_perf_metrics_data(self): 
         lh_perf_metrics_data=[]
-        parse("$.audits.total-byte-weight")
         self.url= self.report['requestedUrl']
         self.fetch_time = self.report['fetchTime']
+        page_size = 0.0
+        score = 0.0
+        first_contentful_paint = 0.0
+        largest_contentful_paint = 0.0
+        first_meaningful_paint = 0.0
+        speed_index = 0.0
+        total_blocking_time = 0.0
+        max_potential_fid = 0.0
+        server_response_time = 0.0
+        interactive = 0.0
         if self.url_category_file!=None:
            self.category = self.url_category.get(self.url,"other")
         try:
            page_size = [match.value['numericValue'] for match in self.jsonpath_page_size.find(self.report) ][0]
            page_size = page_size / 1024
-           speed_index = [match.value['numericValue'] for match in self.jsonpath_speed_index.find(self.report) ][0]
            score = [match.value for match in self.jsonpath_score.find(self.report) ][0]
-           first_meaningful_paint = [match.value['numericValue'] for match in self.jsonpath_first_meaningful_paint.find(self.report) ][0]
            first_contentful_paint = [match.value['numericValue'] for match in self.jsonpath_first_contentful_paint.find(self.report) ][0]
-           time_to_interactive = [match.value['numericValue'] for match in self.jsonpath_interactive.find(self.report) ][0]
+           largest_contentful_paint = [match.value['numericValue'] for match in self.jsonpath_largest_contentful_paint.find(self.report) ][0]
+           first_meaningful_paint = [match.value['numericValue'] for match in self.jsonpath_first_meaningful_paint.find(self.report) ][0]
+           speed_index = [match.value['numericValue'] for match in self.jsonpath_speed_index.find(self.report) ][0]
+           total_blocking_time = [match.value['numericValue'] for match in  self.jsonpath_total_blocking_time.find(self.report) ][0]
            max_potential_fid = [match.value['numericValue'] for match in self.jsonpath_max_potential_fid.find(self.report) ][0]
+           server_response_time = [match.value['numericValue'] for match in self.jsonpath_server_response_time.find(self.report) ][0]
+           interactive = [match.value['numericValue'] for match in self.jsonpath_interactive.find(self.report) ][0]
            self.network_resources = [match.value for match in self.jsonpath_network_resources.find(self.report) ]
         except:
            pass 
-        lh_perf_metrics_data=[self.url,self.fetch_time,self.category,page_size,score,first_contentful_paint,max_potential_fid,time_to_interactive,first_meaningful_paint,speed_index]
+        lh_perf_metrics_data=[self.url,self.fetch_time,self.category,page_size,score,first_contentful_paint,largest_contentful_paint,first_meaningful_paint,speed_index,total_blocking_time,max_potential_fid,server_response_time,interactive]
         self.lh_perf_metrics_data.append(lh_perf_metrics_data)
 
     def find_opportunities_data(self): 
@@ -186,3 +202,4 @@ class LightHouseDataExtract:
                    resource_type = 'Other'
                 if 'startTime' in item and 'endTime' in item:    
                     self.resources_data.append([self.url,self.fetch_time,self.category,item['url'],resource_type,item['startTime'],item['endTime']])
+
